# coding: utf-8

"""
    Mentortools Marketplace Server

    Mentortools service for ingesting payment-provider webhooks into normalized order events

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from marketplace_server_connector.models.integration_out import IntegrationOut  # noqa: E501

class TestIntegrationOut(unittest.TestCase):
    """IntegrationOut unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> IntegrationOut:
        """Test IntegrationOut
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `IntegrationOut`
        """
        model = IntegrationOut()  # noqa: E501
        if include_optional:
            return IntegrationOut(
                id = 56,
                provider = 'digistore',
                platform = 'web',
                flow = 'access',
                is_active = True,
                sync_enabled = True,
                credential_keys = [
                    ''
                    ],
                created_at = 56,
                updated_at = 56
            )
        else:
            return IntegrationOut(
                id = 56,
                provider = 'digistore',
                platform = 'web',
                flow = 'access',
                is_active = True,
                sync_enabled = True,
                credential_keys = [
                    ''
                    ],
                created_at = 56,
                updated_at = 56,
        )
        """

    def testIntegrationOut(self):
        """Test IntegrationOut"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
